@@ -32,6 +32,14 @@ class BodhiProcessor(BaseProcessor):
             'bodhi.mashtask.sync.wait',
             'bodhi.mashtask.sync.done',
             'bodhi.buildroot_override.tag',
+            'bodhi.buildroot_override.untag',
+        ]])
+
+    def handle_link(self, msg, **config):
+        return any([target in msg['topic'] for target in [
+            'bodhi.update.comment',
+            'bodhi.update.request',
+            'bodhi.update.complete',
         ]])
 
     def subtitle(self, msg, **config):
@@ -86,9 +94,21 @@ class BodhiProcessor(BaseProcessor):
             return self._("bodhi masher finished waiting on mirror repos " + \
                           "to sync")
         elif 'bodhi.buildroot_override.tag' in msg['topic']:
-            tmpl = self._(
-                "{submitter} submitted a buildroot override for {build}"
-            )
-            return tmpl.format(**msg['msg']['override'])
+            return self._("{submitter} submitted a buildroot override " +
+                          "for {build}").format(**msg['msg']['override'])
+        elif 'bodhi.buildroot_override.untag' in msg['topic']:
+            return self._("{submitter} expired a buildroot override " +
+                          "for {build}").format(**msg['msg']['override'])
+        else:
+            raise NotImplementedError
+
+    def link(self, msg, **config):
+        tmpl = "https://admin.fedoraproject.org/updates/{title}"
+        if 'bodhi.update.comment' in msg['topic']:
+            return tmpl.format(title=msg['msg']['comment']['update_title'])
+        elif 'bodhi.update.complete' in msg['topic']:
+            return tmpl.format(title=msg['msg']['update']['title'])
+        elif 'bodhi.update.request' in msg['topic']:
+            return tmpl.format(title=msg['msg']['update']['title'])
         else:
             raise NotImplementedError
